@@ -7,7 +7,14 @@
 #ifndef _SAVEHELPER_H_
 #define _SAVEHELPER_H_
 
+#include <QObject>
+
+#include <kauth_version.h>
+#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
+#include <KAuth/ActionReply>
+#else
 #include <KAuth>
+#endif
 
 using namespace KAuth;
 
